@@ -9,12 +9,12 @@ void cfft_r2c(int* n, double* data,
               int* fftwplanopt);
 
 /* complex to real backward */
-void cfft_c2r(int* n, fftw_complex* data,
-              double* res);
+void cfft_c2r(int* nres, int* ndata, fftw_complex* data,
+              double* res, int* fftwplanopt);
 
 /* complex to complex --eitherway */
 void cfft_c2c(int* n, fftw_complex* data,
-              fftw_complex* res, int* inverse);
+              fftw_complex* res, int* inverse, int* fftwplanopt);
 
 void cmvfft_r2c(int *n, int *m, double* data,
                 fftw_complex* res,
